@@ -1,5 +1,11 @@
 name = "csinscapp"
-version = "0.1.1"
+version = "0.1.3"
+
+CLICK = 0
+MOUSE_DOWN = 1  
+MOUSE_MOVE = 2
+MOUSE_OVER = 3
+MOUSE_OUT  = 4
 
 # tested on remi version = "2020.3.10"
 import remi.gui as gui
@@ -356,13 +362,6 @@ class Image (Control):
 
 
 class CSinSCApp:
-
-  CLICK = 0
-  MOUSE_DOWN = 1  
-  MOUSE_MOVE = 2
-  MOUSE_OVER = 3
-  MOUSE_OUT  = 4
-
   buffered_mode = False
 
   resources_cache = {}
@@ -461,35 +460,54 @@ class CSinSCApp:
       return userdata.main()
 
   def on_click(self, widget, control):
-    self.events.append(Event(CSinSCApp.CLICK, control))
+    self.events.append(Event(CLICK, control))
 
   def on_mouse_over(self, widget, control):
-    self.events.append(Event(CSinSCApp.MOUSE_OVER, control))    
+    self.events.append(Event(MOUSE_OVER, control))    
 
   def on_mouse_out(self, widget, control):
-    self.events.append(Event(CSinSCApp.MOUSE_OUT, control))
+    self.events.append(Event(MOUSE_OUT, control))
 
   def on_mouse_down(self, widget, x, y, control):
-    self.events.append(Event(CSinSCApp.MOUSE_DOWN, control, x, y))
+    self.events.append(Event(MOUSE_DOWN, control, x, y))
 
   def on_mouse_move(self, widget, x, y, control):
-    self.events.append(Event(CSinSCApp.MOUSE_MOVE, control, x, y))    
+    self.events.append(Event(MOUSE_MOVE, control, x, y))    
   
-  def get_next_event(self):
-    event = Event(None, None)
+  def get_next_event(self, event_types = None):
+    accept = False
+    event = None
+
     if len(self.events) > 0:
       event = self.events[0]
       del self.events[0]
+      if event_types is None:
+        accept = True
+      elif isinstance(event_types, list):
+        if event.type in event_types:
+          accept = True
+      elif isinstance(event_types, int):
+        if event.type == event_types:
+          accept = True
+          
+    if not accept:
+      event = Event(None, None)
     return event
 
   def wait_for_event(self, event_types = None):
-    bool accept = False
+    accept = False
     while not accept:
       if len(self.events) == 0:
         continue
       event = self.events[0]
       del self.events[0]
-      if event_types is None or event.type in event_types or event.type == event_types:
-        accept = True               
+      if event_types is None:
+        accept = True
+      elif isinstance(event_types, list):
+        if event.type in event_types:
+          accept = True
+      elif isinstance(event_types, int):
+        if event.type == event_types:
+          accept = True
     return event
       
